-- About GoogleMapsSearch.lua
-- February 2012
-- Austin Smith / UMUC
-- This addon will create a Google Maps tab, which can display the patron's address,
-- the lender's address, or a KML file specified in the settings.
--
-- Questions/Comments to asmith341@umuc.edu

local settings = {};
settings.Autodisplay = GetSetting("Autodisplay");
settings.UseKML = GetSetting("Display KML");
settings.url = GetSetting("url");

local interfaceMngr = nil;
local googleMapsForm = {};
googleMapsForm.Form = nil;
googleMapsForm.Browser = nil;
googleMapsForm.RibbonPage = nil;

function Init()
	-- boilerplate for intitializing & displaying an IE tab in a Transaction window.
	interfaceMngr = GetInterfaceManager();
	googleMapsForm.Form = interfaceMngr:CreateForm("Google Maps", "Script");
	googleMapsForm.Browser = googleMapsForm.Form:CreateBrowser("Google Maps", "Google Maps Browser", "Google Maps");
	googleMapsForm.Browser.TextVisible = false;
	googleMapsForm.RibbonPage = googleMapsForm.Form:GetRibbonPage("Google Maps");

	-- create the buttons. Only create the KML button if it's enabled in the settings.
	googleMapsForm.RibbonPage:CreateButton("Display Patron Address", GetClientImage("Search32"), "DisplayPatron", "Google");
	googleMapsForm.RibbonPage:CreateButton("Display Lender Address", GetClientImage("Search32"), "DisplayLender", "Google");
	if settings.UseKML then
		googleMapsForm.RibbonPage:CreateButton("Display KML Map", GetClientImage("Search32"), "DisplayMap", "Google");
	end
	googleMapsForm.Form:Show();
	if settings.Autodisplay then
		if settings.UseKML then
			DisplayMap();
		else
			DisplayPatron();
		end
	end
end

function DisplayMap()

	-- navigate to the map by concatenating the google maps url with the one specified in addon settings.
	googleMapsForm.Browser:Navigate("http://maps.google.com/?q="..settings.url);
end

function DisplayPatron()
	local patronaddress = GetFieldValue("User","Address").."+"..GetFieldValue("User","City").."+"..GetFieldValue("User","State").."+"..GetFieldValue("User","Zip");
	patronaddress = string.gsub(patronaddress ," ","+");
	-- navigate to the map by concatenating the google maps url with the patron's address string
	googleMapsForm.Browser:Navigate("http://maps.google.com/maps?f=q&source=s_q&hl=en&geocode=&q="..patronaddress);

end

function DisplayLender()
	local lender = GetFieldValue("Lender","Address1").."+"..GetFieldValue("Lender","Address2").."+"..GetFieldValue("Lender","Address3");
	if lender ~= nil then
		lender = string.gsub(lender," ","+");
		-- navigate to the map by concatenating the google maps url with the patron's address string
		googleMapsForm.Browser:Navigate("http://maps.google.com/maps?f=q&source=s_q&hl=en&geocode=&q="..lender);
	end
end